# Recurly

This repository houses the official python library for Recurly's V3 API.

> *Note*:
> If you were looking for the V2 client, see the [v2 branch](https://github.com/recurly/recurly-client-python/tree/v2).

### Documentation

This library's [python documentation](https://recurly-client-python.readthedocs.io/en/latest/) is hosted on ReadTheDocs. 
It contains the Getting Started guide as well as the reference documentation.

Documentation for the HTTP API and example code can be found
[on our Developer Portal](https://developers.recurly.com/api/v2019-10-10/).

### Contributing

Please see our [Contributing Guide](CONTRIBUTING.md).
